#SkypeWatch Installer for JAWS
#Version 1.21
#Copyright (c)2009-2010 H.K. Projects
#www.hkprojects.tk
#This software is distributed under the GNU General Public License version 2.0.
#For more information, please see: http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#or view the file License.txt.

import wx
import os
import sys
import shutil
import subprocess
from optparse import OptionParser
import logging
import ctypes
import locale
import gettext
import _winreg
from shlobj import *

#Constants:
__author__="Hrvoje Katic (hrvojekatic@gmail.com)"
__copyright__="Copyright (C) 2009-2010 H.K. Projects (www.hkprojects.tk)"
__version__="1.21"

#Text to be written to Default.JSS file:
constJSSText='''Use "default_fs.jsb"
Use "skypewatch.jsb"

void function _filler()
return
endFunction
'''

#parsing args
parser = OptionParser()
parser.add_option("-v", "--version", dest="version", help="Specify JAWS version number")
parser.add_option("-l", "--language", dest="language", help="Specify JAWS language (ENU is set by default)", default="enu")
parser.add_option("-b", "--backup", action="store_true", dest="backup", default=False, help="Make backup of current files before replacing them")
parser.add_option("-a", "--append", action="store_false", dest="append", default=True, help="Append SkypeWatch information at the end of Default.JSS file, don't overwrite it")
parser.add_option("-i", "--install", action="store_true", dest="install", default=False, help="Install SkypeWatch")
parser.add_option("-r", "--remove", action="store_true", dest="remove", default=False, help="Remove SkypeWatch")
(options, args) = parser.parse_args()

#Global variables:
v=options.version
l=options.language
b=options.backup
if options.append is True: m="w"
else: m="r+"
i=options.install
r=options.remove
if i is False and r is False: i=True
t=True
JUsrDir=None
JLangDir=None

#Getting paths for shared and user data:
getUserDataFolder=SHGetFolderPath(0, CSIDL_APPDATA)
getProgramDataFolder=SHGetFolderPath(0, CSIDL_COMMON_APPDATA)
reg=_winreg.OpenKey(_winreg.HKEY_LOCAL_MACHINE, ur"SOFTWARE\Microsoft\Windows\CurrentVersion")
try: getProgramFiles=_winreg.QueryValueEx(reg, "ProgramW6432Dir")[0]
except: getProgramFiles=SHGetFolderPath(0, CSIDL_PROGRAM_FILES)
getLocaleDir = os.path.join(os.getcwdu(), 'locale')

#Setting up Log file:
logging.basicConfig(level=logging.DEBUG, format='%(asctime)s\n%(levelname)s: %(message)s', filename='SkypeWatchInstaller.log', filemode='w')

#Loading interface language:
locale.setlocale(locale.LC_ALL, '')
try:
	LCID=ctypes.windll.kernel32.GetThreadLocale()
	UILang=locale.windows_locale[LCID]
	gettext.translation('SkypeWatchInstaller', localedir = getLocaleDir, languages=[UILang]).install(True)
except:
	gettext.install('SkypeWatchInstaller',unicode=True)

class SWInstaller(wx.Frame):

	def cmdLineCase(self):
		if os.path.exists("%s%sFreedom Scientific%sJAWS%s%s%sSETTINGS" % (getProgramDataFolder, os.sep, os.sep, os.sep, v, os.sep)) and not os.path.exists("%s%sFreedom Scientific%sJAWS%s%s%sSETTINGS%s%s" % (getProgramDataFolder, os.sep, os.sep, os.sep, v, os.sep, os.sep, l)):
			wx.MessageBox(_("The given language name (%s) was not found in this JAWS version (%s). Exitting program.")%(l,v), _("Error"), wx.OK|wx.ICON_ERROR)
			sys.exit(2)
		if not os.path.exists("%s%sFreedom Scientific%sJAWS%s%s%sSETTINGS%s%s" % (getProgramDataFolder, os.sep, os.sep, os.sep, v, os.sep, os.sep, l)):
			wx.MessageBox(_("Sorry, the given JAWS version (%s) was not found. Exitting program.")%v, _("Error"), wx.OK|wx.ICON_ERROR)
			sys.exit(2)
		else:
			pass
		if i is True:
			self.runInstall()
		if r is True:
			self.startRemoving()
		else:
			logging.info("No arguments given, the application will start normally.")

	def getJFWVersions(self):
		try:
			global JUsrDir
			JUsrDir = ("%s%sFreedom Scientific%sJAWS" % (getProgramDataFolder, os.sep, os.sep))
			self.JFWVerChoices = [x for x in os.listdir(JUsrDir) if os.path.isdir(os.path.join(JUsrDir, x))]
			global v
			v=os.listdir(JUsrDir)[0]
			logging.info("Found %s JAWS installations" % len(os.listdir(JUsrDir)))
			global JLangDir
			JLangDir = ("%s%sFreedom Scientific%sJAWS%s%s%sSETTINGS" % (getUserDataFolder, os.sep, os.sep, os.sep, v, os.sep))
		except:
			logging.exception("No JAWS versions available")
			wx.MessageBox(_("No available JAWS installations found on your system. Exitting program."), _("Error"), wx.OK|wx.ICON_ERROR)
			sys.exit(2)

	def onVersionSelected(self, event):
		global v
		v=event.GetString()
		self.SetStatusText(_("Selected: %s") % v, 1)
		logging.info("JAWS version changed to %s" % v)
		global JLangDir
		JLangDir = ("%s%sFreedom Scientific%sJAWS%s%s%sSETTINGS" % (getUserDataFolder, os.sep, os.sep, os.sep, v, os.sep))
		try:
			self.JFWLangList.Show(True)
			self.JFWLangList.Clear()
			self.JFWLangList.AppendItems([x for x in os.listdir(JLangDir) if os.path.isdir(os.path.join(JLangDir, x))])
			self.setLangSelection()
		except:
			logging.exception("Failed to select JAWS language in version %s"%v)
			self.JFWLangList.Show(False)

	def setLangSelection(self):
		try:
			global l
			l=os.listdir(JLangDir)[0]
			self.JFWLangList.SetSelection(0)
			self.SetStatusText(_("Language: %s") % l, 2)
			logging.info("JAWS locale selection set to %s" % l)
		except:
			logging.exception("Failed to select JAWS language")
			self.JFWLangList.Show(False)

	def onLanguageSelected(self, event):
		global l
		l=event.GetString()
		self.SetStatusText(_("Language: %s") % l, 2)
		logging.info("JAWS locale changed to %s" % l)

	def onMakeBackup(self, event):
		global b
		if self.makeBackup.GetValue():
			b=True
			logging.info("Backup option changed to On")
		else:
			b=False
			logging.info("Backup option changed to Off")

	def onOverwrite(self, event):
		global m
		if self.JSSOverwrite.GetValue():
			m="w"
			logging.info("Overwrite option changed to On")
		else:
			m="r+"
			logging.info("Overwrite option changed to Off")

	def SetValue(self, event):
		global i
		global r
		i = str(self.RBInstall.GetValue())
		r = str(self.RBRemove.GetValue())
		if i is "True":
			logging.info("Program action changed to Install")
		if r is "True":
			logging.info("Program action changed to Remove")

	def onTerminateChoice(self, event):
		global t
		if self.terminateChoice.GetValue():
			t=True
			logging.info("Terminate program at the end of procedure option changed to on")
		else:
			t=False
			logging.info("Terminate program at the end of procedure option changed to off")

	def caseTerminate(self):
		if t is True:
			logging.info("Terminating program.")
			sys.exit(2)
		else: pass

	def onExecute(self, event):
		if i is "True":
			logging.info("Execute Button clicked, running Install option")
			self.installSkypeWatch(event)
		if r is "True":
			logging.info("Execute Button clicked, running Remove option")
			self.removeSkypeWatch(event)
		else:
			pass

	def getPath(self):
		self.PublicDefaultJSB = "%s%sFreedom Scientific%sJAWS%s%s%sSETTINGS%s%s%sDefault.JSB" % (getProgramDataFolder, os.sep, os.sep, os.sep, v, os.sep, os.sep, l, os.sep)
		self.UserDefaultJSB = "%s%sFreedom Scientific%sJAWS%s%s%sSETTINGS%s%s%sDefault.JSB" % (getUserDataFolder, os.sep, os.sep, os.sep, v, os.sep, os.sep, l, os.sep)
		self.UserJFWPath = "%s%sFreedom Scientific%sJAWS%s%s%sSETTINGS%s%s" % (getUserDataFolder, os.sep, os.sep, os.sep, v, os.sep, os.sep, l)
		self.renameFromDefault_JSB = "%s%sDefault.JSB" % (self.UserJFWPath, os.sep)
		self.renameToDefault_FS_JSB = "%s%sDefault_FS.JSB" % (self.UserJFWPath, os.sep)
		self.Default_JSS_Path = "%s%sFreedom Scientific%sJAWS%s%s%sSETTINGS%s%s%sDefault.JSS" % (getUserDataFolder, os.sep, os.sep, os.sep, v, os.sep, os.sep, l, os.sep)
		self.Default_FS_JSB_Path = "%s%sFreedom Scientific%sJAWS%s%s%sSETTINGS%s%s%sDefault_FS.JSB" % (getUserDataFolder, os.sep, os.sep, os.sep, v, os.sep, os.sep, l, os.sep)
		self.runScriptCompiler = "%s%sFreedom Scientific%sJAWS%s%s%sscompile.exe" % (getProgramFiles, os.sep, os.sep, os.sep, v, os.sep)

	def installSkypeWatch(self, event):
		logging.info("The Install option started successfully")
		self.getPath()
		if not os.path.exists(self.Default_JSS_Path):
			global m
			m="w"
		if not os.path.exists(self.UserJFWPath) or not os.path.exists("%s%sskypewatch.jsb" % (self.UserJFWPath, os.sep)):
			wx.MessageBox(_("This JAWS version is corrupted or has no JAWS scripts for Skype installed. Please check your JAWS installation and try again."), _("Error"), wx.OK|wx.ICON_ERROR)
			logging.error("Corrupted JAWS version or no scripts for Skype installed in %s" % self.UserJFWPath)
			pass
		if os.path.exists(self.UserJFWPath) and os.path.exists("%s%sskypewatch.jsb" % (self.UserJFWPath, os.sep)):
			iq = wx.MessageBox(_("The selected JAWS version is %s, language %s. Are you sure you want to install SkypeWatch information?") % (v, l), _("Confirm"), wx.YES_NO | wx.YES_DEFAULT, self)
			if iq == wx.YES:
				logging.info("Yes Button clicked, starting installer.")
				self.runInstall()
			if iq == wx.NO:
				logging.info("NO Button clicked, giving up.!")
				pass

	def removeSkypeWatch(self, event):
		logging.info("The Remove option started successfully")
		rq = wx.MessageBox(_("The selected JAWS version is %s, language %s. Are you sure you want to remove SkypeWatch information?") % (v, l), _("Confirm"), wx.YES_NO | wx.YES_DEFAULT, self)
		if rq == wx.YES:
			logging.info("Yes Button clicked, starting uninstaller.")
			self.startRemoving()
		if rq == wx.NO:
			logging.info("NO Button clicked, giving up!")
			pass

	def onHelp(self, event):
		logging.info("Help Button clicked")
		ReadMe = "%s%sDocs%s%s%sReadMe.html" % (os.getcwdu(), os.sep, os.sep, UILang.split('_')[0], os.sep)
		enReadMe = "%s%sDocs%sen_US%sReadMe.HTML" % (os.getcwdu(), os.sep, os.sep, os.sep)
		try:
			os.startfile(ReadMe)
			logging.info("ReadMe started successfully from path %s" % ReadMe)
		except os.error:
			try:
				os.startfile(enReadMe)
				logging.info("ReadMe started successfully from path %s" % ReadMe)
			except os.error:
				wx.MessageBox(_("Couldn't find ReadMe file."), _("Error"), wx.OK|wx.ICON_ERROR)
				logging.error("Couldn't find path %s" % ReadMe)

	def onAbout(self, event):
		logging.info("About Button clicked")
		wx.MessageBox(_("""
SkypeWatch Installer for JAWS
Version %s
%s

This software is distributed under the GNU General Public License version 2.0.
For more information, please see: http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
or view the file License.txt.

For questions, comments and suggestions, please send E-Mail to: %s.
""") % (__version__, __copyright__, __author__), _("About SkypeWatch Installer"), wx.OK|wx.ICON_INFORMATION)
		logging.info("About box closed")

	def onClose(self, event):
		logging.info("Close Button clicked")
		logging.info("Exitting program")
		sys.exit()

	def backItUp(self):
		logging.info("Backup started")
		self.getPath()
		self.BDir = "%s%sSkypeWatch Installer Backup" % (self.UserJFWPath, os.sep)
		logging.info("Creating backup folder in %s" % self.BDir)
		if not os.path.exists(self.BDir):
			try:
				os.mkdir(self.BDir)
				logging.info("Backup directory created successfully")
			except:
				logging.exception("Failed to create a backup directory")
		else:
			logging.info("Backup directory already exists")
			pass
		if os.path.exists(self.UserDefaultJSB):
			logging.info("Searching for Default.JSB in %s" % self.UserDefaultJSB)
			try:
				shutil.copy(self.UserDefaultJSB, self.BDir)
			except:
				logging.exception("Failed to copy %s to %s" % (self.UserDefaultJSB, self.BDir))
		if os.path.exists(self.Default_JSS_Path):
			logging.info("Searching for Default.JSS in %s" % self.Default_JSS_Path)
			try:
				shutil.copy(self.Default_JSS_Path, self.BDir)
			except:
				logging.exception("Failed to copy %s to %s" % (self.Default_JSS_Path, self.BDir))
		if os.path.exists(self.Default_FS_JSB_Path):
			logging.info("Searching for Default_FS.JSB in %s" % self.Default_FS_JSB_Path)
			try:
				shutil.copy(self.Default_FS_JSB_Path, self.BDir)
			except:
				logging.exception("Failed to copy %s to %s" % (self.Default_FS_JSB_Path, self.BDir))

	def runInstall(self):
		completedStage1=False
		completedStage2=False
		completedStage3=False
		completedStage4=False
		completedStage5=False
		completedStage6=False
		aborted=False
		logging.info("Starting installer")
		self.getPath()
		if b is True:
			logging.info("Backup is turned on, so running a backup")
			self.backItUp()
		else:
			logging.info("Backup is turned off, so skipping backup")
			pass
		if not os.path.exists(self.UserDefaultJSB) and not os.path.exists(self.Default_FS_JSB_Path) and not os.path.exists(self.Default_JSS_Path):
			completedStage1=True
		else:
			logging.info("SkypeWatch Installation already present in this version of JAWS")
			w = wx.MessageBox(_("The SkypeWatch support has been already installed in this JAWS version. Should I remove and reinstall it?"), _("SkypeWatch Installer for JAWS"), wx.YES_NO | wx.YES_DEFAULT | wx.ICON_QUESTION)
			if w == wx.YES:
				logging.info("Asked for reinstall, Yes Button clicked")
				self.runUninstall()
				completedStage1=True
			if w == wx.NO:
				completedStage1=False
				aborted=True
				self.caseTerminate()
		if completedStage1 is True:
			try:
				shutil.copy(self.PublicDefaultJSB, self.UserJFWPath)
				logging.info("Copying Default.JSB to User Settings successful")
				completedStage2=True
			except:
				logging.exception("Cannot copy %s to %s" % (self.PublicDefaultJSB, self.UserJFWPath))
				pass; completedStage2=False
		if completedStage2 is True:
			try:
				os.rename(self.renameFromDefault_JSB, self.renameToDefault_FS_JSB)
				logging.info("Renaming Default.JSB to Default_FS.JSB successful")
				completedStage3=True
			except:
				logging.exception("Cannot rename %s to %s" % (self.renameFromDefault_JSB, self.renameToDefault_FS_JSB))
				pass; completedStage3=False
		if completedStage3 is True:
			try:
				JSS = open(self.Default_JSS_Path, m)
				logging.info("Opening Default.JSS for writing")
				completedStage4=True
			except:
				logging.exception("Failed to open Default.JSS for writing")
				completedStage4=False
		if completedStage4 is True:
			try:
				if m=="r+":
					text=JSS.read()
					if 'Use "default_fs.jsb"' in text or 'Use "skypewatch.jsb"' in text or 'void function _filler()' in text:
						logging.info("Data already present in Default.JSS, writing canceled.")
					else:
						logging.info("Appending information to Default.JSS")
						JSS.seek(len(text))
						JSS.write(constJSSText)
				else:
					logging.info("Writing information to Default.JSS")
					JSS.write(constJSSText)
				JSS.close()
				logging.info("Closing Default.JSS")
				completedStage5=True
			except:
				logging.exception("Failed to write into Default.JSS")
				pass; completedStage5=False
		if completedStage5 is True:
			try:
				subprocess.check_call([u"%s"%self.runScriptCompiler, u"%s"%self.Default_JSS_Path])
				logging.info("Running %s, recompiling Default.JSS" % self.runScriptCompiler)
				completedStage6=True
			except:
				logging.exception("Failed to compile Default.JSS, couldn't find %s" % self.runScriptCompiler)
				pass; completedStage6=False
		if completedStage1 is True and completedStage2 is True and completedStage3 is True and completedStage4 is True and completedStage5 is True and completedStage6 is True:
			wx.MessageBox(_("SkypeWatch installation completed successfully!"), _("Done!"), wx.OK|wx.ICON_EXCLAMATION)
			logging.info("SkypeWatch Installation completed")
		else:
			if aborted is False: wx.MessageBox(_("Sorry, but SkypeWatch installation failed. Please check your JAWS installation and try again."), _("Error"), wx.OK|wx.ICON_ERROR)
			logging.info("SkypeWatch Installation failed or aborted.")
		self.caseTerminate()

	def runUninstall(self):
		logging.info("Starting uninstaller")
		self.getPath()
		if b is True:
			logging.info("Backup is set to On, so backing up current files")
			self.backItUp()
		else:
			logging.info("Backup is set to Off, so no backup needed")
			pass
		if os.path.exists(self.UserDefaultJSB):
			try:
				os.remove(self.UserDefaultJSB)
				logging.info("File %s removed" % self.UserDefaultJSB)
			except:
				logging.exception("Failed to remove %s" % self.UserDefaultJSB)
		if os.path.exists(self.Default_FS_JSB_Path):
			try:
				os.remove(self.Default_FS_JSB_Path)
				logging.info("File %s removed" % self.Default_FS_JSB_Path)
			except:
				logging.exception("Failed to remove %s" % self.Default_FS_JSB_Path)
		if os.path.exists(self.Default_JSS_Path) and m=="w":
			try:
				os.remove(self.Default_JSS_Path)
				logging.info("File %s removed" % self.Default_JSS_Path)
			except:
				logging.exception("Failed to remove %s" % self.Default_JSS_Path)
		wx.MessageBox(_("SkypeWatch removal completed successfully! Choose OK to continue installing SkypeWatch."), _("Done!"), wx.OK|wx.ICON_EXCLAMATION)

	def startRemoving(self):
		logging.info("Removing files")
		self.getPath()
		if os.path.exists(self.UserDefaultJSB):
			try:
				os.remove(self.UserDefaultJSB)
				logging.info("File %s removed" % self.UserDefaultJSB)
			except:
				logging.exception("Failed to remove %s" % self.UserDefaultJSB)
		if os.path.exists(self.Default_FS_JSB_Path):
			try:
				os.remove(self.Default_FS_JSB_Path)
				logging.info("File %s removed" % self.Default_FS_JSB_Path)
			except:
				logging.exception("Failed to remove %s" % self.Default_FS_JSB_Path)
		if os.path.exists(self.Default_JSS_Path) and m=="w":
			try:
				os.remove(self.Default_JSS_Path)
				logging.info("File %s removed" % self.Default_JSS_Path)
			except:
				logging.exception("Failed to remove %s" % self.Default_JSS_Path)
		restore1 = "%s%sSkypeWatch Installer Backup%sDefault.JSB" % (self.UserJFWPath, os.sep, os.sep)
		if os.path.exists(restore1):
			try:
				shutil.copy(restore1, self.UserJFWPath)
				logging.info("%s restored to JAWS User Folder" % restore1)
			except:
				logging.exception("Failed to restore %s to JAWS User Folder" % restore1)
			try:
				os.remove(restore1)
				logging.info("%s removed from backup folder" % restore1)
			except:
				logging.exception("Failed to remove %s" % restore1)
		restore2 = "%s%sSkypeWatch Installer Backup%sDefault.JSS" % (self.UserJFWPath, os.sep, os.sep)
		if os.path.exists(restore2):
			try:
				if os.path.exists(self.Default_JSS_Path): os.remove(self.Default_JSS_Path)
				shutil.copy(restore2, self.UserJFWPath)
				logging.info("%s restored to JAWS User Folder" % restore2)
			except:
				logging.exception("Failed to restore %s to JAWS User Folder" % restore2)
			try:
				os.remove(restore2)
				logging.info("%s removed from backup folder" % restore2)
			except:
				logging.exception("Failed to remove %s" % restore2)
		restore3 = "%s%sSkypeWatch Installer Backup%sDefault_FS.JSB" % (self.UserJFWPath, os.sep, os.sep)
		if os.path.exists(restore3):
			try:
				shutil.copy(restore3, self.UserJFWPath)
				logging.info("%s restored to JAWS User Folder" % restore3)
			except:
				logging.exception("Failed to restore %s to JAWS User Folder" % restore3)
			try:
				os.remove(restore3)
				logging.info("%s removed from backup folder" % restore3)
			except:
				logging.exception("Failed to remove %s" % restore3)
		wx.MessageBox(_("SkypeWatch removal completed successfully!"), _("Done!"), wx.OK|wx.ICON_EXCLAMATION)
		logging.info("Removal complete")
		self.caseTerminate()

#Creating a GUI:
	def __init__(self, parent, id, title):
		if v==None:
			self.getJFWVersions()
		else:
			self.cmdLineCase()
		wx.Frame.__init__(self, parent, id, title, size=(700, 600))
		self.MainPanel = wx.Panel(self, -1)
		self.Centre()
		self.Show(True)
		self.MainSizer = wx.BoxSizer(wx.VERTICAL)
		self.CreateStatusBar(3)
		self.SetStatusText(_("Found: %d") % len(os.listdir(JUsrDir)), 0)

		self.JFWVerLabel = wx.StaticText(self.MainPanel, -1, _("Select JAWS &Version:"))
		self.JFWVerList = wx.Choice(self.MainPanel, -1, choices = self.JFWVerChoices)
		try:
			self.JFWVerList.SetFocus()
			self.JFWVerList.SetSelection(0)
			self.SetStatusText(_("Selected: %s") % v, 1)
			logging.info("JAWS version selection set to %s" % v)
		except:
			logging.exception("Failed to select JAWS version")
			self.JFWVerList.Show(False)
		self.JFWVerList.Bind(wx.EVT_CHOICE, self.onVersionSelected)
		self.MainSizer.Add(self.JFWVerLabel, 0, wx.ALL, 10)
		self.MainSizer.Add(self.JFWVerList, 0, wx.ALL, 10)

		self.JFWLangLabel = wx.StaticText(self.MainPanel, -1, _("Select JAWS &Language Folder:"))
		self.JFWLangList = wx.Choice(self.MainPanel, -1, choices = [x for x in os.listdir(JLangDir) if os.path.isdir(os.path.join(JLangDir, x))])
		self.setLangSelection()
		self.JFWLangList.Bind(wx.EVT_CHOICE, self.onLanguageSelected)
		self.MainSizer.Add(self.JFWLangLabel, 0, wx.ALL, 10)
		self.MainSizer.Add(self.JFWLangList, 0, wx.ALL, 10)

		self.makeBackup = wx.CheckBox(self.MainPanel, -1, _("Make &backup"))
		self.makeBackup.SetValue(False)
		self.Bind(wx.EVT_CHECKBOX, self.onMakeBackup, self.makeBackup)
		self.MainSizer.Add(self.makeBackup, 0, wx.ALL, 10)
		logging.info("Backup option set to Off")

		self.JSSOverwrite = wx.CheckBox(self.MainPanel, -1, _("&Overwrite Default.JSS"))
		self.JSSOverwrite.SetValue(True)
		self.Bind(wx.EVT_CHECKBOX, self.onOverwrite, self.JSSOverwrite)
		self.MainSizer.Add(self.JSSOverwrite, 0, wx.ALL, 10)
		logging.info("Overwrite option set to On")

		self.ActionsLabel = wx.StaticBox(self.MainPanel, -1, _("Available actions"))
		self.Actions = wx.StaticBoxSizer(self.ActionsLabel, wx.HORIZONTAL)
		self.RBInstall = wx.RadioButton(self.MainPanel, -1, _("&Install SkypeWatch"), (10, 10), style=wx.RB_GROUP)
		self.RBRemove = wx.RadioButton(self.MainPanel, -1, _("&Remove SkypeWatch"), (10, 50))
		self.Actions.Add(self.RBInstall, 0, wx.ALIGN_LEFT, 10)
		self.Actions.Add(self.RBRemove, 0, wx.ALIGN_RIGHT, 10)
		self.Bind(wx.EVT_RADIOBUTTON, self.SetValue, id=self.RBInstall.GetId())
		self.Bind(wx.EVT_RADIOBUTTON, self.SetValue, id=self.RBRemove.GetId())
		self.MainSizer.Add( self.Actions, 0, wx.ALIGN_CENTRE, 10)
		self.SetValue(True)

		self.terminateChoice = wx.CheckBox(self.MainPanel, -1, _("&Terminate program at the end of procedure"))
		self.terminateChoice.SetValue(True)
		self.Bind(wx.EVT_CHECKBOX, self.onTerminateChoice, self.terminateChoice)
		self.MainSizer.Add(self.terminateChoice, 0, wx.ALL, 10)
		logging.info("Terminate program at the end of procedure option set to on")

		self.Execute = wx.Button(self.MainPanel, -1, _("&Execute"))
		self.Bind(wx.EVT_BUTTON, self.onExecute, self.Execute)
		self.MainSizer.Add(self.Execute, 0, wx.ALIGN_RIGHT, 10)

		Help = wx.Button(self.MainPanel, -1, _("&Help"))
		self.Bind(wx.EVT_BUTTON, self.onHelp, Help)
		self.MainSizer.Add(Help, 0, wx.ALL, 10)

		About = wx.Button(self.MainPanel, -1, _("&About"))
		self.Bind(wx.EVT_BUTTON, self.onAbout, About)
		self.MainSizer.Add(About, 0, wx.ALL, 10)

		Close = wx.Button(self.MainPanel, -1, _("&Close"))
		self.Bind(wx.EVT_BUTTON, self.onClose, Close)
		self.MainSizer.Add(Close, 0, wx.ALIGN_RIGHT, 10)

		self.MainPanel.SetSizer(self.MainSizer)
		self.MainPanel.Layout()

app = wx.App()
SWInstaller(None, -1, _("SkypeWatch Installer for JAWS"))
app.MainLoop()
